from setuptools import setup, find_packages

setup(
	name='raname',
	version='0.1',
	description='Random Name Generator | Use Free APIs',
	author='Itsaoda',
	author_email='febyzamsee@gmail.com',
	install_requires=[
		'requests>=2.23.0',
	],
	classifiers=[
		'Development Status :: 3 - Alpha',
		'Intended Audience :: Developers',
		'Topic :: Software Development :: Libraries :: Python Modules',
		'License :: OSI Approved :: MIT License',
		'Programming Language :: Python :: 3.11',
	],
)
